use crate::{config::DriveConfig, run_command};

use super::str_vec;

// TODO : Add support for using entire block device

pub fn format_drives(conf: &DriveConfig, encrypted: bool) {
    // EFI (BOOT)
    run_command(
        &str_vec(vec!["mkfs.vfat", "-F", "32", conf.boot.as_str()]),
        None,
        false,
    );

    // ROOT
    if encrypted {
        run_command(
            &str_vec(vec!["cryptsetup", "luksFormat", conf.root.as_str()]),
            None,
            true,
        );
    } else {
        run_command(&str_vec(vec!["mkfs.ext4", conf.root.as_str()]), None, false);
    }
}

// MOUNT

pub fn mount_drives(conf: &DriveConfig, encrypted: bool) {
    if encrypted {
        run_command(
            &str_vec(vec!["cryptsetup", "open", conf.root.as_str(), "root"]),
            None,
            true,
        );

        run_command(
            &str_vec(vec!["mount", "/dev/mapper/root", "/mnt"]),
            None,
            false,
        );
    } else {
        run_command(
            &str_vec(vec!["mount", conf.root.as_str(), "/mnt"]),
            None,
            false,
        );
    }

    run_command(
        &str_vec(vec![
            "mount",
            "--mkdir",
            conf.boot.as_str(),
            "/mnt/boot",
            "-o",
            "rw,nosuid,nodev,noatime,fmask=0137,dmask=0027",
        ]),
        None,
        false,
    );
}
